## 📖 Agentes Se auto melhorando
  - Conceito: o agente tem capacidade de se auto melhorar primeiro iniciaremos com a seleção do modelo pelo proprio agente com base em niveis de complexidade da tarefa
  - Anotacoes: 


